CustomDio class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
download(
String url, String savePath, {dynamic onReceiveProgress(int total, int received, int chunkSize)?, CustomCancelToken? cancelToken, bool deleteIfExist = false, Map< String, dynamic> ? headers, int? startByte}) → Future<int> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited